@@ -14,7 +14,7 @@ package MCE::Core::Input::Request;
 use strict;
 use warnings;
 
-our $VERSION = '1.831';
+our $VERSION = '1.832';
 
 ## Items below are folded into MCE.
 
@@ -99,7 +99,7 @@ sub _worker_request_chunk {
    _WORKER_REQUEST_CHUNK__NEXT:
 
    while (1) {
-      undef $_ if (length > MAX_CHUNK_SIZE);
+      undef $_ if (length > MAX_GC_SIZE);
 
       $_ = '';
 
