@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.831';
+our $VERSION = '1.832';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -192,7 +192,7 @@ sub run_seq (&@) {
       $_begin = $_[0]->[0]; $_end = $_[0]->[1];
       $_params->{$_pid}{sequence} = $_[0];
    }
-   elsif (ref $_[0] eq '') {
+   elsif (ref $_[0] eq '' || ref($_[0]) =~ /^Math::/) {
       $_begin = $_[0]; $_end = $_[1];
       $_params->{$_pid}{sequence} = [ @_ ];
    }
@@ -365,7 +365,7 @@ MCE::Loop - MCE model for building parallel loops
 
 =head1 VERSION
 
-This document describes MCE::Loop version 1.831
+This document describes MCE::Loop version 1.832
 
 =head1 DESCRIPTION
 
